@@ -195,7 +195,8 @@ def metadata(args, parse_obj: Optional[Parse] = None):
     print(f"PARSING SCORES ONE AFTER THE OTHER...")
     p.parse_scores(parallel=False)
     modified_score_files = p.update_score_metadata_from_tsv(write_empty_values=args.empty,
-                                                            remove_unused_fields=args.remove)
+                                                            remove_unused_fields=args.remove,
+                                                            write_text_fields=args.prelims)
     if len(modified_score_files) == 0:
         print("Nothing to update.")
         return
@@ -208,9 +209,9 @@ def metadata(args, parse_obj: Optional[Parse] = None):
     print(f"Operation resulted in {changed} updated score{'s' if changed != 1 else ''}.")
 
 
-def repair(args):
-    print("Sorry, the command has not been implemented yet.")
-    print(args.dir)
+# def repair(args):
+#     print("Sorry, the command has not been implemented yet.")
+#     print(args.dir)
 
 
 def transform(args, parse_obj: Optional[Parse] = None):
@@ -628,12 +629,15 @@ In particular, check DCML harmony labels for syntactic correctness.""", parents=
                                   help="Set this flag to remove non-default metadata fields that are not columns in the metadata.tsv file anymore.")
     metadata_parser.add_argument('-s', '--suffix', metavar='SUFFIX',
                             help='Suffix of the new scores with updated metadata fields.')
+    metadata_parser.add_argument('-p', '--prelims', action='store_true',
+                                 help="Pass this flag if, in addition to updating metadata fields, you also want score headers to be updated "
+                                      "from the columns title_text, subtitle_text, composer_text, lyricist_text, part_name_text.")
     metadata_parser.set_defaults(func=metadata)
-
-    repair_parser = subparsers.add_parser('repair',
-                                          help="Apply automatic repairs to your uncompressed MuseScore files.",
-                                          parents=[parse_args])
-    repair_parser.set_defaults(func=repair)
+    #
+    # repair_parser = subparsers.add_parser('repair',
+    #                                       help="Apply automatic repairs to your uncompressed MuseScore files.",
+    #                                       parents=[parse_args])
+    # repair_parser.set_defaults(func=repair)
 
     review_parser = subparsers.add_parser('review',
                                           help="Extract facets, check labels, and create _reviewed files.",
